@@ -1,7 +1,7 @@
 package App::CSVUtils;
 
 our $DATE = '2016-11-16'; # DATE
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 use 5.010001;
 use strict;
@@ -115,7 +115,7 @@ my %arg_filename_0 = (
     },
 );
 
-my %arg_filenames = (
+my %arg_filenames_0 = (
     filenames => {
         'x.name.is_plural' => 1,
         summary => 'Input CSV files',
@@ -148,6 +148,19 @@ my %arg_field_1_nocomp = (
     },
 );
 
+my %arg_fields_1 = (
+    fields => {
+        'x.name.is_plural' => 1,
+        summary => 'Field names',
+        schema => ['array*', of=>'str*'],
+        cmdline_aliases => { F=>{} },
+        req => 1,
+        pos => 1,
+        greedy => 1,
+        element_completion => \&_complete_field,
+    },
+);
+
 my %arg_eval_2 = (
     eval => {
         summary => 'Perl code to do munging',
@@ -210,6 +223,7 @@ $SPEC{csvutil} = {
                 'avg',
                 'select-row',
                 'convert-to-hash',
+                'select-fields',
             ]],
             req => 1,
             pos => 0,
@@ -248,6 +262,7 @@ sub csvutil {
 
     my $code;
     my $field_idx;
+    my $field_idxs;
     my $sorted_fields;
     my @summary_row;
     my $selected_row;
@@ -383,13 +398,34 @@ sub csvutil {
             }
             $res .= _get_csv_row($csv, $row, $i);
         } elsif ($action eq 'delete-field') {
-            unless (defined $field_idx) {
-                $field_idx = _get_field_idx($args{field}, \%field_idxs);
-                if (@$row <= 1) {
-                    return [412, "Can't delete field because CSV will have zero fields"];
+            if (!defined($field_idxs)) {
+                $field_idxs = [];
+                for my $f (@{ $args{_fields} }) {
+                    push @$field_idxs, _get_field_idx($f, \%field_idxs);
+                }
+                $field_idxs = [sort {$b<=>$a} @$field_idxs];
+                for (@$field_idxs) {
+                    splice @$row, $_, 1;
+                    unless (@$row) {
+                        return [412, "Can't delete field(s) because CSV will have zero fields"];
+                    }
+                }
+            } else {
+                for (@$field_idxs) {
+                    splice @$row, $_, 1;
                 }
             }
-            splice @$row, $field_idx, 1;
+            $res .= _get_csv_row($csv, $row, $i);
+        } elsif ($action eq 'select-fields') {
+            if (!defined($field_idxs)) {
+                $field_idxs = [];
+                my %seen;
+                for my $f (@{ $args{_fields} }) {
+                    return [400, "Duplicate field '$f'"] if $seen{$f}++;
+                    push @$field_idxs, _get_field_idx($f, \%field_idxs);
+                }
+            }
+            $row = [map { $row->[$_] } @$field_idxs];
             $res .= _get_csv_row($csv, $row, $i);
         } elsif ($action eq 'sort-fields') {
             unless ($i == 1) {
@@ -520,15 +556,15 @@ sub csv_list_field_names {
 
 $SPEC{csv_delete_field} = {
     v => 1.1,
-    summary => 'Delete a field from CSV file',
+    summary => 'Delete one or more fields from CSV file',
     args => {
         %arg_filename_0,
-        %arg_field_1,
+        %arg_fields_1,
     },
 };
 sub csv_delete_field {
     my %args = @_;
-    csvutil(%args, action=>'delete-field');
+    csvutil(%args, action=>'delete-field', _fields => $args{fields});
 }
 
 $SPEC{csv_munge_field} = {
@@ -731,7 +767,7 @@ will result in:
 
 _
     args => {
-        %arg_filenames,
+        %arg_filenames_0,
     },
 };
 sub csv_concat {
@@ -789,6 +825,19 @@ sub csv_concat {
     [200, "OK", $res, {"cmdline.skip_format"=>1}];
 }
 
+$SPEC{csv_select_fields} = {
+    v => 1.1,
+    summary => 'Only output selected field(s)',
+    args => {
+        %arg_filename_0,
+        %arg_fields_1,
+    },
+};
+sub csv_select_fields {
+    my %args = @_;
+    csvutil(%args, action=>'select-fields', _fields => $args{fields});
+}
+
 1;
 # ABSTRACT: CLI utilities related to CSV
 
@@ -804,7 +853,7 @@ App::CSVUtils - CLI utilities related to CSV
 
 =head1 VERSION
 
-This document describes version 0.009 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2016-11-16.
+This document describes version 0.010 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2016-11-16.
 
 =head1 DESCRIPTION
 
@@ -1020,7 +1069,7 @@ Return value:  (any)
 
 =head2 csv_delete_field(%args) -> [status, msg, result, meta]
 
-Delete a field from CSV file.
+Delete one or more fields from CSV file.
 
 This function is not exported.
 
@@ -1028,9 +1077,9 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<field>* => I<str>
+=item * B<fields>* => I<array[str]>
 
-Field name.
+Field names.
 
 =item * B<filename>* => I<filename>
 
@@ -1155,6 +1204,38 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 csv_select_fields(%args) -> [status, msg, result, meta]
+
+Only output selected field(s).
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<fields>* => I<array[str]>
+
+Field names.
+
+=item * B<filename>* => I<filename>
+
+Input CSV file.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 csv_select_row(%args) -> [status, msg, result, meta]
 
 Only output specified row(s).
